# saving window when data acquisition complete---acqs.tcl

set acqssavepath on-line/specs
set ebyefile EbyEData

set acqsfile ""
set acqsfrom "Scaler"
set acqscomment {}

load_preferences

if {[info exists preferences(savepath)]} then {
   set acqssavepath $preferences(savepath)
} else {
   set preferences(savepath) $acqssavepath
   update_preferences
}

proc acqs-report to {set-footer "Data Saved to $to"}

proc click-acqs-save {} {
	global sdresource acqsdir acqsfile acqscomment acqsfrom
	set c 0
	set z 0

   if {$acqsdir != ""} then {
      set acqspath $acqsdir/$acqsfile
   } else {
      set acqspath $acqsfile
   }

	set-footer "saving /$sdresource/$acqsfrom..."
	set z [catch {exec copy-spectrum /$sdresource/$acqsfrom $acqspath} m]
	set-footer $m
	if {$z==0} then {
		if {$acqscomment!={}} then {
			eg "(spectrum :name '$acqspath' :label '$acqscomment')"
		}
		after 2000 acqs-report $acqspath
	}
	clear-busy
}

proc acqs-start-frame {} {
   global acqscomment

   set-busy
   make-acqsframe

   set acqscomment {}

   acqs-default-dir
#   acqs-default-file
   acqs-repaint
}

proc acqs-repaint {} {
   global acqsdir acqsfrom acqscomment

   :modify ACQS-COMMENT :value "$acqscomment"
   :modify ACQS-DIR     :value $acqsdir
   :modify ACQS-FROM    :value $acqsfrom
}

proc delete-a-spectrum s {
   global EGallow
   set a $EGallow
   set EGallow 0x30000
   catch { EG "spectrum :name '$s' !delete" }
   set EGallow $a
   return
}

proc acqs-temp-save s {
   global  acqsdir acqsfile sdresource acqscomment acqsfrom

   set acqsfrom $s

   set-busy
   set acqscomment {}
   acqs-default-dir
   acqs-default-file $s

   set c 0
   set z 0

   if {$acqsdir != ""} then {
      set acqspath $acqsdir/$acqsfile
   } else {
      set acqspath $acqsfile
   }
   set acqstemp $acqspath.tmp

   set-footer "saving /$sdresource/$acqsfrom..."
   set z [catch {exec copy-spectrum /$sdresource/$acqsfrom $acqstemp} m]

   if {$z==0} then {
      delete-a-spectrum $acqspath
      set z [catch {exec copy-spectrum $acqstemp $acqspath} mm]
      delete-a-spectrum $acqstemp
   }
   set-footer $m
   if {$z==0} then {
      if {$acqscomment!={}} then {
         eg "(spectrum :name '$acqspath' :label '$acqscomment')"
      }
         after 2000 acqs-report $acqspath
   }
   clear-busy
}

proc acqs-auto-save s {
   global  acqsdir acqsfile sdresource acqscomment acqsfrom

   set acqsfrom $s

   set-busy
   set acqscomment {}
   acqs-default-dir
   acqs-default-file $s

   set c 0
   set z 0

   if {$acqsdir != ""} then {
      set acqspath $acqsdir/$acqsfile
   } else {
      set acqspath $acqsfile
   }

   set-footer "saving /$sdresource/$acqsfrom..."
   set z [catch {exec copy-spectrum /$sdresource/$acqsfrom $acqspath} m]
   set-footer $m
   if {$z==0} then {
      if {$acqscomment!={}} then {
         eg "(spectrum :name '$acqspath' :label '$acqscomment')"
      }
         after 2000 acqs-report $acqspath
   }
   clear-busy
}

proc acqs-auto-write-ebye {s t} {
   global  acqsdir acqsfile sdresource acqscomment acqsfrom
   global  ebyefile env

   set-busy
   set acqscomment {}
   acqs-default-dir

   acqs-default-file $s
   if {$acqsdir != ""} then {
      set acqsfrom $acqsdir/$acqsfile
   } else {
      set acqsfrom $acqsfile
   }

   acqs-default-file $ebyefile
   if {$acqsdir != ""} then {
      set acqspath $acqsdir/$acqsfile
   } else {
      set acqspath $acqsfile
   }
   if {[string first / $acqspath] != 0} then {
      set acqspath [file join $env(HOME) $acqspath]
   }
   if {$t} {
      set acqspath [set acqspath].tmp
      set ap "-a"
   } else {
      set ap ""
   }

   set acqsfrom $s

   set-footer "saving data from /$sdresource/$acqsfrom..."
   set z [catch {exec save-laser-events $ap /$sdresource/$acqsfrom $acqspath} m]
   set-footer $m
   if {!$t && $z==0} then {
      after 2000 acqs-report $acqspath
   }
   clear-busy
}

proc click-acqs-dir dir {
   global acqsdir
   set acqsdir $dir
   acqs-repaint
}

proc click-acqs-comment comment {
   global acqscomment
   set acqscomment $comment
   acqs-repaint
}

proc click-acqs-from from {
   global acqsfrom
   set acqsfrom $from
   acqs-repaint
}

proc acqs-default-file s {
   global acqsfile acqscomment
   set acqsfile run[run-num-read].$s
}

proc acqs-default-dir {} {
   global acqsdir acqscomment acqssavepath
   set acqsdir $acqssavepath
}

proc click-acqs arg {
   global debug
   if {$debug} then {puts stderr "click with argument \{$arg\}"}
   set f [lindex $arg 0]
   set c [lindex $arg 1]
   set w [lindex $arg 2]
   set v [lindex $arg 3]
   switch $w {
	ACQS-SAVE          {click-acqs-save}
	ACQS-DIR           {click-acqs-dir $v}
	ACQS-COMMENT       {click-acqs-comment $v}
	ACQS-FROM          {click-acqs-from $v}
	default           {puts stdout $arg}
   }
}

proc make-acqsframe {} {
  global acqsfrom

   :frame [self frame-name].acqs :label "Data Acquisition Complete" :transient T
   :panel ACQS-PANEL :padx 5 :pady 5
   :layout H; :col-gap 10; :row-gap 10
   :button ACQS-SAVE :label Save
   :next-row T
   :text ACQS-FROM :label Save: :valuex 12c :w 35 :value "$acqsfrom"
   :next-row T
   :text ACQS-DIR  :label To:   :valuex 12c :w 35 :value ""
   :next-row T
   :text ACQS-COMMENT :label Comment: :valuex 12c :w 35 :value ""
# :focus T

 :show T
}
