#   laser/tcl/calib.tcl
#     12/02/00   DAC calibration for Laser group

set debug 0
set started 0

set frame CAL
set frametitle "Laser DAC Calibration"
set icontitle  "Calibration"

set testchan 0

proc show-cal-val {} {
   global modulename

   set mv [third [ersread $modulename.Status]]
   update-widget CAL-VAL [expr int($mv)]
}

proc set-test-chan {} {
   global modulename dacstep testchan EGallow
   set ega $EGallow; set EGallow 0x2000a
   set m [erswrite $modulename.Channel $testchan]
   if {$m == $EGallow} then {midas-warning "Coudn't set the channel number.\nData Acquisition may be going."}
   set EGallow $ega
   inform acq update-run-status
}

proc update-channel-parameters {} {
   global parameters chans dacstep dacmax dacmaxmv dwell settle
   read-parameters
   update-widget CAL-CHANS   $chans
   update-widget CAL-DAC-MAX $dacmaxmv
}

proc click-cal-test v {
   global testchan chans
   if {$v < $chans} then {
      set testchan $v
   }
   update-widget CAL-TEST $testchan
   set-test-chan
   click-redisplay
}

proc click-redisplay {} {
   global started
   if {!$started} then return
   set-footer "Updating display"
   update-channel-parameters
   show-cal-val
   set-footer "Display Updated [date]"
}   

proc start args {
   global started
   if {$started == 0} then {
      make-frame
      set-test-chan
   } else {open-frame}
   set started 1
   click-redisplay
}

proc click-quit args {
   click-cal-test 0
   close-frame [first $args]
}

proc make-frame {} {
  global env

  :frame [self frame-name] :label "[self frame-title]" :show-footer T \
      :icon-image "@$env(ICONHOME)/vme_module" \
      :icon-name "[self icon-title]" :resize F

      :panel PA :layout H :padx 10 :pady 10
      :layout H; :col-gap 10; :row-gap 10

      :text CAL-CHANS :label "Number of Channels:" :w 5 :deaf T :valuex 17c
      :text CAL-DAC-MAX :label "Max. DAC Voltage (mV):" :w 10 :deaf T :valuex 22c
      :next-row T

      :panel PB :layout B :padx 10 :pady 5 :after FOOTER
      :layout H; :col-gap 10;
      :number CAL-TEST :label "Test Channel:" :min 0 :max 2047 :w 5 :valuex 17c
      :text CAL-VAL :label "DAC Voltage (mV):" :w 10 :deaf T :valuex 18c

   :panel PD :padx 5 :pady 10 :layout B :after FOOTER
   :layout H; :col-gap 20; :row-gap 10
      :button B0    :label "0" :command "click-cal-test 0"
      :button B49    :label "49" :command "click-cal-test 49"
      :button B99    :label "99" :command "click-cal-test 99"
      :button B149    :label "149" :command "click-cal-test 149"
      :button B199    :label "199" :command "click-cal-test 199"
:col-gap 40
      :button QUIT    :label "QUIT" :colour red :command "click-quit"
      :next-row T;  :col-gap 10
      :button B20    :label "20" :command "click-cal-test 20"
      :button B40    :label "40" :command "click-cal-test 40"
      :button B60    :label "60" :command "click-cal-test 60"
      :button B80    :label "80" :command "click-cal-test 80"
      :button B120    :label "120" :command "click-cal-test 120"
      :button B140    :label "140" :command "click-cal-test 140"
      :button B160    :label "160" :command "click-cal-test 160"
      :button B180    :label "180" :command "click-cal-test 180"


   :show T
}
